function BuildTreeMaxNodes(Nmax,fname)


%  Builds a quadtree with a fixed bound on the total number of nodes
%  internal and leafs
%  Nmax: maximum number of nodes  (must be greater or equal than 1)
%  fname: file name with prior information; for the moment supports
%  only square regions
%  Note: will override global variable tree, if any. 
%  This function may take quite some time; did not think to an
%  efficient implementation yet
%  See LoadFullTree

global tree;

LoadFullTree(fname);

depths = cell2mat({tree(:).depth});
maxdepth = tree(numel(tree)).depth;
internal = find(depths<maxdepth);

disparity = zeros(size(internal));

for i = 1:numel(disparity)
    children_p = [tree(tree(i).NW).p tree(tree(i).NE).p ...
        tree(tree(i).SE).p tree(tree(i).SW).p ];
    disparity(i) = max(children_p) - min(children_p);
end

[Y,I] = sort(disparity); % start pruning from the internal nodes
% with smallest disparity

left = numel(tree); % nodes left in the tree
j = 1;

while left > Nmax % keep pruning as long as objective not met
    to_cut = I(j);
    tree(to_cut).leaf = 1; % internal node becomes leaf;eliminates children
    left = left - NumberOfDescendants(to_cut);
    j = j+1;
end

newtree(left) = tree(1); % creates new result;
newtree(1) = tree(1); % initializes root

j = 1;
free_pos = 2; % first free position in the new tree
inserted = 1; % number of nodes inserted in the new tree
orig_pos = zeros(1,left); % lookup table
orig_pos(1) = 1;
while inserted < left
    if newtree(j).leaf == 0 % internal node?
        newtree(free_pos) = tree(tree(orig_pos(j)).NW);
        orig_pos(free_pos) = tree(orig_pos(j)).NW;
        newtree(free_pos+1) = tree(tree(orig_pos(j)).NE);
        orig_pos(free_pos+1) = tree(orig_pos(j)).NE;
        newtree(free_pos+2) = tree(tree(orig_pos(j)).SE);
        orig_pos(free_pos+2) = tree(orig_pos(j)).SE;
        newtree(free_pos+3) = tree(tree(orig_pos(j)).SW);
        orig_pos(free_pos+3) = tree(orig_pos(j)).SW;
        newtree(free_pos).parent = j;
        newtree(free_pos+1).parent = j;
        newtree(free_pos+2).parent = j;
        newtree(free_pos+3).parent = j;
        newtree(j).NW = free_pos;
        newtree(j).NE = free_pos + 1;
        newtree(j).SE = free_pos + 2;
        newtree(j).SW = free_pos + 3;
        inserted = inserted + 4;
        free_pos = free_pos + 4;
    end
    j = j+1;
end


tree = newtree;

function n = NumberOfDescendants(pos)

global tree

if tree(pos).leaf == 1
    n = 4;
else % could happen in pathological cases...
   n = NumberOfDescendants(tree(pos).NW) +  NumberOfDescendants(tree(pos).NE) + ...
       NumberOfDescendants(tree(pos).SE) + NumberOfDescendants(tree(pos).SW);
end