function d = Distance(i,j)

%
% Computes the distance between two nodes in the quadtree. It can
% consider Euclidean distance in the plance only (on the x,y plane) or the
% cost/bonus for ascending/descending as well.
% i,j: integer indexes of the vertices being considered. Cost is to move
% from i to j. Note that cost my be asymmetric because of differences in
% ascent/descent costs/bonuses
%

global tree;

% both of these must be >=0 but could also be both 0
global cost_ascend; % cost increase for ascending
global bonus_descend; % bonus for descending 

p1 = [tree(i).xc tree(i).yc]; % start position
p2 = [tree(j).xc tree(j).yc]; % goal position

depth1 = tree(i).depth;
depth2 = tree(j).depth;

d = norm(p1-p2);

if ( depth1 > depth2 ) % i deeper than j? Ascending
    d = d + cost_ascend*(depth1-depth2);
elseif ( depth1 < depth2 ) % j deeper than i? Descending
    d = d - bonus_descend*(depth2-depth1);
end