%
%  This script plots an illustrative partitioned PQMap including an
%  annotated searcher route to demonstrate ascent, level, and descent
%  transit segments
%
%  Used to generate the following figures for 2011-ICRA paper
%   - 'fig-PQMap_DistanceDefn.png'
%   - 'fig-PQMap_DistanceDefn_labelled.png'
%   - 'fig-PQMap_DistanceDefn_annoteA.png'
%   - 'fig-PQMap_DistanceDefn_annoteB.png'
%
close all; clc;

BuildTreeMaxNodes(5,'init_belief_map_256.mat');

LocateAndSplit(20,212)
LocateAndSplit(200,40)

h_PQMap = DrawQuadTree;
figure(h_PQMap); 
set(gcf, 'color', 'white');
set(gca, 'FontSize', 14);
grid off;

% labelTree


pos_vec = [32,4,5,9,16,20];
hold on;
h_sensor = zeros(size(pos_vec));
h_text = zeros(size(pos_vec));

for n = 1:length(pos_vec)
    
    h_sensor(n) = plot(tree(pos_vec(n)).xc, tree(pos_vec(n)).yc ,'bo', 'MarkerSize', 6, 'MarkerFaceColor', 'b' );  % searcher position

    if (n>1)
       h_line(n) = plot( [tree(pos_vec(n-1)).xc; tree(pos_vec(n)).xc], [tree(pos_vec(n-1)).yc; tree(pos_vec(n)).yc], 'b:');
    end
    h_text(n) = text( tree(pos_vec(n)).xc+2, tree(pos_vec(n)).yc+2, sprintf('n_%d', n-1 ) );
    
end
set(h_text, 'FontSize', 12, 'FontWeight', 'bold');
set(h_line(2:n), 'LineWidth', 2);

hold off;
