%
%  This script plots the evolution of the aggregate belief as well as the
%       trajectory of the searcher as it moves through the region.
%
%  Used to generate the following figures for 2011-ICRA paper
%   - 'fig-BeliefEvol_MaxNodes300.png'
%   - 'fig-SearchTraj_MaxNodes300.png'
%
close all; clc; clc;

% Load the data file for the hierarchical search simulation runs
datafile = 'good_run';    %
load( datafile );

belief_evol(1) = [];
belief_traj(1) = [];

%================
% Plot the aggregate belief evolution
%
figure;
set(gcf, 'color', 'white', 'Position', [360 377 676 301] );
hold on;

h_evol = plot( 0:length(belief_evol)-1, belief_evol );

set(h_evol, 'LineWidth', 3);


set(gca, 'FontSize', 14);
set(gca, 'XLim', [0, 400], 'YLim', [0 1]);

xlabel('Time step, t'); ylabel('Aggregate belief, P(H)');


% disp('Press ENTER to continue');
% pause

h_searcher = plot( 0, belief_evol(1), 'ro', 'MarkerSize', 10, 'MarkerFaceColor', 'red');  % searcher position


Movie1(1) = getframe(gcf);


%================
% Plot the searcher's trajectory
%
curr_dir = pwd;
%cd('../../../../Projects/MultiScaleSearch/Type1PQ/');
h_quad = DrawQuadTree;
cd(curr_dir);

set(h_quad, 'color', 'white');

set(gca, 'FontSize', 14);
h_path = plot(-100, -100, 'b:', 'LineWidth', 2);
h_sensor(1) = plot( tree(belief_traj(1)).xc, tree(belief_traj(1)).yc, 'ro', 'MarkerSize', 10, 'MarkerFaceColor', 'white');  % searcher position
h_sensor(2) = plot( tree(belief_traj(1)).xc, tree(belief_traj(1)).yc, 'ro', 'MarkerSize', 10, 'MarkerFaceColor', 'r' );  % searcher position
traj_xy = [];
Movie2(1) = getframe(gcf);


% Iterate over time of the search process
for t = 1:length(belief_traj)
    t
   % if (ismember(t,[20, 45, 160, 240, 370]))
   %     pause
   % end
    hold on;
    
    % Determine current position and add to trajectory
    c_curr = belief_traj(t);
    traj_xy = [traj_xy; tree( c_curr ).xc, tree( c_curr ).yc];
    
    
    % Annotating desired search location on quad tree diagram
    %  - don't need to recreate object since quad tree figure is NOT redrawn
    set( h_sensor(2), 'XData', tree( c_curr ).xc, 'YData', tree( c_curr ).yc);
    set( h_path, 'XData', traj_xy(:,1), 'YData', traj_xy(:,2) );
    Movie2(t+1) = getframe(gcf);
    hold off;

    % Update evolution
    set( h_searcher, 'XData', t, 'YData', belief_evol(t) );
   Movie1(t+1) = getframe(gcf);
     pause(0.005)
%     
    
end         % end for(t)

movie2avi(Movie1,'movie1.avi','compression','none');
movie2avi(Movie2,'movie2.avi','compression','none');

% Plot markers on evolution plot
delete(h_searcher)
figure(1)
hold on;
pts = [45, 160, 240, 377];
for i = 1:length(pts)
    plot( pts(i), belief_evol(pts(i)), 'ro', 'MarkerSize', 10, 'MarkerFaceColor', 'red');  % searcher position
    h_text(i) = text( pts(i), belief_evol(pts(i)) + 0.075, ...
        sprintf('t=%d', pts(i)) );
end
set(h_text, 'FontSize', 14);
hold off;





