function [maxNodeInd] = GetMaximumPositionUniform(c_curr)

% generates valid sense position with maximal objective value
% objective function:
%    (1-q(c)) * 4^d(c) / min_cost(c, c_curr)

% This version considers also the travel cost between the current position
% and the optimal next sense position. The parameter c_curr is the index in
% the tree where the robot performed the last sensing position


global tree;


% Compute node with maximal objective value
maxNodeInd = 1;        % initialize as root
maxNodeVal = -inf;%tree(maxNodeInd).p * 4^(tree(maxNodeInd).depth-1) / 1;


% Search entire tree (linearly through tree data structure)
for which_ind = 1:size(tree,2)
    
    if ( which_ind ~= c_curr ) % does not consider staying there (transit cost would be 0...)
        if (tree(which_ind).leaf == 1 ) % consider only leaves (necessary for uniform search
            if ( ~tree(which_ind).cleared )     % check that this node is not cleared
                
                % Compute transit cost between current position and this element's position
                min_cost = Distance(c_curr,which_ind);
                
                % Evaluate objective function
                objValue = tree(which_ind).p * 4^(tree(which_ind).depth-1) / min_cost;
                %objValue = tree(which_ind).p;
                % Compare with current maximal node
                if ( objValue > maxNodeVal )        % ignore equality case intentionally
                    % Update to this node
                    maxNodeVal = objValue;
                    maxNodeInd = which_ind;
                end         % end if(max value check)
                
            end         % end if(this node is not yet cleared)
        end
    end
    
end         % end for(which_node)


% % Return center coordinate of the node with maximal objective value
% x = tree(maxNodeInd).xc;
% y = tree(maxNodeInd).yc;

% Return instead the index of the node with maximal objective value

