function index = LocateAndSplit(x,y)

%  Given a valid sensing location (x,y), searches the tree for a square
%  having (x,y) as center. If found, returns the index. If not found
%  iteratively refine the tree until if finds it.
%  Important: (x,y) must be a valid search position (no error checking)

global tree;
global epsilon;
global treeFigureHandler;

% seek the quadrant to update

found = 0;

index = 1; % starts from the root
current = tree(index);

while found == 0
    
    if  ( abs(current.xc-x) < epsilon )  && ( abs(current.yc-y) < epsilon )
        found = 1; 
    else % not found yet...
        if current.leaf == 0 % if internal node, descend into the right subtree
            if  ( x < current.xc ) && ( y > current.yc )
                index = current.NW;
            elseif  ( x > current.xc ) && ( y > current.yc )
                index = current.NE;
            elseif  ( x > current.xc ) && ( y < current.yc )
                index = current.SE;
            elseif  ( x < current.xc ) && ( y < current.yc )
                index = current.SW;
            end
            current = tree(index);
        else % if on a leaf, split the node and continue search from there
            current = SplitNode(index);
            % commented out 'cause it's very slow
          %DrawQuadTree(treeFigureHandler);
       
        end
    end
    
end

